==> jc-1.4.0.tar.gz: javax/net/ssl/SSLKeyException.h <==
// public class javax.net.ssl.SSLKeyException

// class file dependencies
// @dep_class 4e0a56550c69d57c java_io_IOException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class d1cfa534e15939af javax_net_ssl_SSLException
// @dep_class fbf44cb71740b75c javax_net_ssl_SSLKeyException

// header file dependencies
// @dep_header javax_net_ssl_SSLException

#include "javax/net/ssl/SSLException.h"

#ifndef _JC_javax_net_ssl_SSLKeyException_H_
#define _JC_javax_net_ssl_SSLKeyException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_net_ssl_SSLKeyException$sub_refs	_jc_javax_net_ssl_SSLKeyException$sub_refs;
typedef struct _jc_javax_net_ssl_SSLKeyException$sub_nonrefs	_jc_javax_net_ssl_SSLKeyException$sub_nonrefs;
typedef struct _jc_javax_net_ssl_SSLKeyException$refs	_jc_javax_net_ssl_SSLKeyException$refs;
typedef struct _jc_javax_net_ssl_SSLKeyException$nonrefs	_jc_javax_net_ssl_SSLKeyException$nonrefs;
typedef struct _jc_javax_net_ssl_SSLKeyException$object	_jc_javax_net_ssl_SSLKeyException$object;

typedef const struct _jc_javax_net_ssl_SSLKeyException$vmethods	_jc_javax_net_ssl_SSLKeyException$vmethods;
typedef const struct _jc_javax_net_ssl_SSLKeyException$vtable	_jc_javax_net_ssl_SSLKeyException$vtable;
typedef const struct _jc_javax_net_ssl_SSLKeyException$vtype	_jc_javax_net_ssl_SSLKeyException$vtype;

// Constructors
extern void _jc_javax_net_ssl_SSLKeyException$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_net_ssl_SSLKeyException$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_javax_net_ssl_SSLKeyException$vmethods {
};

// Vtable
struct _jc_javax_net_ssl_SSLKeyException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_io_IOException$vmethods	java_io_IOException;
	_jc_javax_net_ssl_SSLException$vmethods	javax_net_ssl_SSLException;
	_jc_javax_net_ssl_SSLKeyException$vmethods	javax_net_ssl_SSLKeyException;
};

// Vtype
struct _jc_javax_net_ssl_SSLKeyException$vtype {
	_jc_type			type;
	_jc_javax_net_ssl_SSLKeyException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_net_ssl_SSLKeyException$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_net_ssl_SSLKeyException$refs {
    _jc_javax_net_ssl_SSLKeyException$sub_refs	javax_net_ssl_SSLKeyException;
    _jc_javax_net_ssl_SSLException$sub_refs	javax_net_ssl_SSLException;
    _jc_java_io_IOException$sub_refs	java_io_IOException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_net_ssl_SSLKeyException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_net_ssl_SSLKeyException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_io_IOException$sub_nonrefs	java_io_IOException;
    _jc_javax_net_ssl_SSLException$sub_nonrefs	javax_net_ssl_SSLException;
    _jc_javax_net_ssl_SSLKeyException$sub_nonrefs	javax_net_ssl_SSLKeyException;
};

// Object instance structure
struct _jc_javax_net_ssl_SSLKeyException$object {
	_jc_javax_net_ssl_SSLKeyException$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_net_ssl_SSLKeyException$vtype	*vtype;
	_jc_javax_net_ssl_SSLKeyException$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_net_ssl_SSLKeyException$vtype _jc_javax_net_ssl_SSLKeyException$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_net_ssl_SSLKeyException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_net_ssl_SSLKeyException$class_object;

#endif	/* _JC_javax_net_ssl_SSLKeyException_H_ */

==> jc-1.4.6.tar.gz: javax/net/ssl/SSLKeyException.h <==
// public class javax.net.ssl.SSLKeyException

// class file dependencies
// @dep_class 4e0a56550c69d57c java_io_IOException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class d1cfa534e15939af javax_net_ssl_SSLException
// @dep_class fbf44cb71740b75c javax_net_ssl_SSLKeyException

// header file dependencies
// @dep_header javax_net_ssl_SSLException

#include "javax/net/ssl/SSLException.h"

#ifndef _JC_javax_net_ssl_SSLKeyException_H_
#define _JC_javax_net_ssl_SSLKeyException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_net_ssl_SSLKeyException$sub_refs	_jc_javax_net_ssl_SSLKeyException$sub_refs;
typedef struct _jc_javax_net_ssl_SSLKeyException$sub_nonrefs	_jc_javax_net_ssl_SSLKeyException$sub_nonrefs;
typedef struct _jc_javax_net_ssl_SSLKeyException$refs	_jc_javax_net_ssl_SSLKeyException$refs;
typedef struct _jc_javax_net_ssl_SSLKeyException$nonrefs	_jc_javax_net_ssl_SSLKeyException$nonrefs;
typedef struct _jc_javax_net_ssl_SSLKeyException$object	_jc_javax_net_ssl_SSLKeyException$object;

typedef const struct _jc_javax_net_ssl_SSLKeyException$vmethods	_jc_javax_net_ssl_SSLKeyException$vmethods;
typedef const struct _jc_javax_net_ssl_SSLKeyException$vtable	_jc_javax_net_ssl_SSLKeyException$vtable;
typedef const struct _jc_javax_net_ssl_SSLKeyException$vtype	_jc_javax_net_ssl_SSLKeyException$vtype;

// Constructors
extern void _jc_javax_net_ssl_SSLKeyException$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_net_ssl_SSLKeyException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_net_ssl_SSLKeyException$vmethods {
};

// Vtable
struct _jc_javax_net_ssl_SSLKeyException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_io_IOException$vmethods	java_io_IOException;
	_jc_javax_net_ssl_SSLException$vmethods	javax_net_ssl_SSLException;
	_jc_javax_net_ssl_SSLKeyException$vmethods	javax_net_ssl_SSLKeyException;
};

// Vtype
struct _jc_javax_net_ssl_SSLKeyException$vtype {
	_jc_type			type;
	_jc_javax_net_ssl_SSLKeyException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_net_ssl_SSLKeyException$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_net_ssl_SSLKeyException$refs {
    _jc_javax_net_ssl_SSLKeyException$sub_refs	javax_net_ssl_SSLKeyException;
    _jc_javax_net_ssl_SSLException$sub_refs	javax_net_ssl_SSLException;
    _jc_java_io_IOException$sub_refs	java_io_IOException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_net_ssl_SSLKeyException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_net_ssl_SSLKeyException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_io_IOException$sub_nonrefs	java_io_IOException;
    _jc_javax_net_ssl_SSLException$sub_nonrefs	javax_net_ssl_SSLException;
    _jc_javax_net_ssl_SSLKeyException$sub_nonrefs	javax_net_ssl_SSLKeyException;
};

// Object instance structure
struct _jc_javax_net_ssl_SSLKeyException$object {
	_jc_javax_net_ssl_SSLKeyException$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_net_ssl_SSLKeyException$vtype	*vtype;
	_jc_javax_net_ssl_SSLKeyException$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_net_ssl_SSLKeyException$vtype _jc_javax_net_ssl_SSLKeyException$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_net_ssl_SSLKeyException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_net_ssl_SSLKeyException$class_object;

#endif	/* _JC_javax_net_ssl_SSLKeyException_H_ */
